@@ -1,3 +1,6 @@
+#use "topfind";;
+#require "opam-file-format";;
+
 let name = "topkg"
 
 let parse filename =
